==> dl.php?src=linea21_1_6.zip: linea21/resources/menurub.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage resources
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 * 'Resource' module is used by 'Publication' and 'Workshop' modules
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight($mod_inc)) ReloadIndex('admin');
///////////

if($todo=='add_l' || $todo=='add_m' || $todo=='add_b') $title=_t('resources','add');
if($todo=='add_l') $title.=" '"._t('resources','link_res')."'";
if($todo=='add_m') $title.=" '"._t('resources','multi_res')."'";
if($todo=='add_b') $title.=" '"._t('resources','biblio_res')."'";
if($todo=='mod_l' || $todo=='mod_m' || $todo=='mod_b') $title=_t('resources','mod');
if($todo=='mod_l') $title.=" '"._t('resources','link_res')."'";
if($todo=='mod_m') $title.=" '"._t('resources','multi_res')."'";
if($todo=='mod_b') $title.=" '"._t('resources','biblio_res')."'";
if($todo=='sup') $title=_t('resources','sup');
if($type=='W') $rub_link_back="?rub=workshoprep&amp;todo=det&amp;id=".$parent;
if($type=='P') $rub_link_back="?rub=publication&amp;todo=det&amp;id=".$parent;
$search="search.php?rub=".$mod_inc;
?>
<div id="itemenu">
<h1><?php echo cutText($title, 30, 1); ?></h1>
<div class="contentlink"><a href="<?php echo $rub_link_back; ?>"
	id="content_link_back"
	title="<?php echo _t('resources','go_back')._t('resources',$mod_inc.'_type'); ?>"><?php echo _t('resources','go_back')._t('resources',$mod_inc.'_type'); ?></a>
| <a href="<?php echo $search; ?>" id="content_link_search"
	title="<?php echo _t('menu','search');?>"><?php echo _t('menu','search');?></a>
</div>
</div>

==> dl.php?src=linea21_1_7.zip: linea21/resources/menurub.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage resources
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 * 'Resource' module is used by 'Publication' and 'Workshop' modules
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight($mod_inc)) ReloadIndex('admin');
///////////

if($todo=='add_l' || $todo=='add_m' || $todo=='add_b') $title=_t('resources','add');
if($todo=='add_l') $title.=" '"._t('resources','link_res')."'";
if($todo=='add_m') $title.=" '"._t('resources','multi_res')."'";
if($todo=='add_b') $title.=" '"._t('resources','biblio_res')."'";
if($todo=='mod_l' || $todo=='mod_m' || $todo=='mod_b') $title=_t('resources','mod');
if($todo=='mod_l') $title.=" '"._t('resources','link_res')."'";
if($todo=='mod_m') $title.=" '"._t('resources','multi_res')."'";
if($todo=='mod_b') $title.=" '"._t('resources','biblio_res')."'";
if($todo=='sup') $title=_t('resources','sup');
if($type=='W') $rub_link_back="?rub=workshoprep&amp;todo=det&amp;id=".$parent;
if($type=='P') $rub_link_back="?rub=publication&amp;todo=det&amp;id=".$parent;
$search="search.php?rub=".$mod_inc;
?>
<div id="itemenu">
	<h1><?php echo cutText($title, 30, 1); ?></h1>
	<div class="contentlink"><a href="<?php echo $rub_link_back; ?>" title="<?php echo _t('resources','go_back')._t('resources',$mod_inc.'_type'); ?>"><i class="icon-level-up"></i><?php echo _t('resources','go_back')._t('resources',$mod_inc.'_type'); ?></a>
	| <a href="<?php echo $search; ?>" title="<?php echo _t('menu','search');?>"><i class="icon-search"></i><?php echo _t('menu','search');?></a>
	</div>
</div>
